import math

def r2p(x, y):
    m = math.sqrt(x * x + y * y)
    a = math.atan2(y, x)
    return m, a, math.degrees(a)

def p2r(m, a_deg):
    a = math.radians(a_deg)
    return m * math.cos(a), m * math.sin(a)

def add(m1, a1, m2, a2):
    x1, y1 = p2r(m1, a1)
    x2, y2 = p2r(m2, a2)
    return r2p(x1 + x2, y1 + y2)

def sub(m1, a1, m2, a2):
    x1, y1 = p2r(m1, a1)
    x2, y2 = p2r(m2, a2)
    return r2p(x1 - x2, y1 - y2)

def mul(m1, a1, m2, a2):
    return m1 * m2, a1 + a2

def div(m1, a1, m2, a2):
    if m2 == 0:
        raise ValueError("Division by zero")
    return m1 / m2, a1 - a2

def main():
    while True:
        print("")
        print("1: Rectangular to Polar")
        print("2: Polar to Rectangular")
        print("3: Add two phasors")
        print("4: Subtract two phasors")
        print("5: Multiply two phasors")
        print("6: Divide two phasors")
        print("0: Exit")
        c = input("Choice: ")
        
        if c == "1":
            x = float(input("x: "))
            y = float(input("y: "))
            m, a, a_deg = r2p(x, y)
            print("Result: m={:.4f}, rad={:.4f}, deg={:.4f}".format(m, a, a_deg))
        elif c == "2":
            m = float(input("m: "))
            a = float(input("angle (deg): "))
            x, y = p2r(m, a)
            print("Result: x={:.4f}, y={:.4f}".format(x, y))
        elif c == "3":
            print("Phasor 1:")
            m1 = float(input("m1: "))
            a1 = float(input("angle1 (deg): "))
            print("Phasor 2:")
            m2 = float(input("m2: "))
            a2 = float(input("angle2 (deg): "))
            m, a, a_deg = add(m1, a1, m2, a2)
            print("Result: m={:.4f}, deg={:.4f}".format(m, a_deg))
        elif c == "4":
            print("Phasor 1:")
            m1 = float(input("m1: "))
            a1 = float(input("angle1 (deg): "))
            print("Phasor 2:")
            m2 = float(input("m2: "))
            a2 = float(input("angle2 (deg): "))
            m, a, a_deg = sub(m1, a1, m2, a2)
            print("Result: m={:.4f}, deg={:.4f}".format(m, a_deg))
        elif c == "5":
            print("Phasor 1:")
            m1 = float(input("m1: "))
            a1 = float(input("angle1 (deg): "))
            print("Phasor 2:")
            m2 = float(input("m2: "))
            a2 = float(input("angle2 (deg): "))
            m, a = mul(m1, a1, m2, a2)
            print("Result: m={:.4f}, deg={:.4f}".format(m, a))
        elif c == "6":
            print("Phasor 1:")
            m1 = float(input("m1: "))
            a1 = float(input("angle1 (deg): "))
            print("Phasor 2:")
            m2 = float(input("m2: "))
            a2 = float(input("angle2 (deg): "))
            m, a = div(m1, a1, m2, a2)
            print("Result: m={:.4f}, deg={:.4f}".format(m, a))
        elif c == "0":
            print("Exiting program.")
            break
        else:
            print("Invalid choice.")
            
        input("Press Enter to continue...")

# Automatically start the program without needing to type main()
main()
